@@ -37,15 +37,10 @@ class DiagramDraw(blockdiag.DiagramDraw.DiagramDraw):
         self._draw_trunklines()
 
     def _draw_trunklines(self):
+        metrix = self.metrix.originalMetrix()
         for network in self.diagram.networks:
-            m = self.metrix.network(network)
-
+            m = metrix.network(network)
             self.drawer.line(m.trunkline, fill=self.fill)
-            if network.display_label:
-                self.drawer.textarea(m.textbox, network.display_label,
-                                     fill=self.fill, halign="right",
-                                     font=self.font,
-                                     fontsize=self.metrix.fontSize)
 
             # FIXME: first network links to global network
             if network == self.diagram.networks[0]:
@@ -54,6 +49,20 @@ class DiagramDraw(blockdiag.DiagramDraw.DiagramDraw):
 
                 self.drawer.line([pt0, pt1], fill=self.fill)
 
+    def draw(self):
+        super(DiagramDraw, self).draw()
+
+        self._draw_trunkline_labels()
+
+    def _draw_trunkline_labels(self):
+        for network in self.diagram.networks:
+            if network.display_label:
+                m = self.metrix.network(network)
+                self.drawer.textarea(m.textbox, network.display_label,
+                                     fill=self.fill, halign="right",
+                                     font=self.font,
+                                     fontsize=self.metrix.fontSize)
+
     def node(self, node, **kwargs):
         m = self.metrix
 
