@@ -50,6 +50,7 @@ from blockdiag.utils.namedtuple import namedtuple
 ENCODING = 'utf-8'
 
 Graph = namedtuple('Graph', 'type id stmts')
+Network = namedtuple('Network', 'id stmts')
 SubGraph = namedtuple('SubGraph', 'id stmts')
 Node = namedtuple('Node', 'id attrs')
 Attr = namedtuple('Attr', 'name value')
@@ -109,8 +110,21 @@ def parse(seq):
     node_stmt = node_id + attr_list >> unarg(Node)
     # We use a forward_decl becaue of circular definitions like (stmt_list ->
     # stmt -> subgraph -> stmt_list)
+    group_stmt = (
+        graph_attr
+        | node_stmt
+    )
+    group_stmt_list = many(group_stmt + skip(maybe(op(';'))))
+    group = (
+        skip(n('group')) +
+        maybe(id) +
+        op_('{') +
+        group_stmt_list +
+        op_('}')
+        >> unarg(SubGraph))
     network_stmt = (
         graph_attr
+        | group
         | node_stmt
     )
     network_stmt_list = many(network_stmt + skip(maybe(op(';'))))
@@ -120,9 +134,10 @@ def parse(seq):
         op_('{') +
         network_stmt_list +
         op_('}')
-        >> unarg(SubGraph))
+        >> unarg(Network))
     stmt = (
         network
+        | group
         | graph_attr
     )
     stmt_list = many(stmt + skip(maybe(op(';'))))
